@@ -12,11 +12,13 @@
 
 #' @export
 # works for nondecision densities, check if works for estDstarM output.
-getSter = function(res) {
-  stopifnot(class(res) == 'D*M')
-  if (names(res)[1] == 'r.hat') {
+getSter <- function(res) {
+  
+  if (is.DstarM.fitND(res)) {
     return(apply(res$r.hat, 2, nth.cmomentS, x = res$tt, nth = 2))
-  } else {
+  } else if (is.DstarM.fitD(res)) {
     return(res$var.dat - res$var.m)
+  } else {
+    stop("res should be output from either estDstarM or estND.")
   }
 }
